==> open-xchange-guard_2.4.0.orig.tar.bz2: open-xchange-guard-2.4.0/com.openexchange.guard/src/com/openexchange/guard/pgp/decryption/PGPDecryptionResult.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.pgp.decryption;

import java.io.InputStream;

/**
 * Represents a decryption result
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public class PGPDecryptionResult {

    private final boolean hasSignature;
    private final boolean signatureVerified;
    private final InputStream inputStream;
    private final String error;
    private final String contentType;


    /***
     *
     * Initializes a new {@link PGPDecryptionResult}.
     *
     * @param inputStream An inputStream to the decrypted data
     * @param contentType the data's content-type if available 
     * @param hasSignature True, if the data was signed, false otherwise
     * @param signatureVerified True, if the data was signed and could be verified during decryption, false otherwise
     * @param error error value 
     */
    public PGPDecryptionResult(InputStream inputStream, String contentType, boolean hasSignature, boolean signatureVerified, String error) {
        this.inputStream = inputStream;
        this.contentType = contentType;
        this.hasSignature = hasSignature;
        this.signatureVerified = signatureVerified;
        this.error = error;
    }

    /**
     * @return True, if the data was signed, false otherwise
     */
    public boolean hasSignature() {
        return hasSignature;
    }

    /**
     * @return True, if the data was signed and could be verified during decryption, false otherwise
     */
    public boolean isSignatureVerified() {
        return signatureVerified;
    }

    /**
     * @return An InputStream to the decrypted data
     */
    public InputStream getInputStream() {
        return inputStream;
    }
    
    /**
     * Gets the contentType
     *
     * @return The contentType
     */
    public String getContentType() {
        return contentType;
    }

    /**
     * Return error if any
     * @return
     */
    public String getError() {
        return error;
    }

    /**
     * return true if has error
     * @return
     */
    public boolean hasError() {
        return (error != null);
    }
}

==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard/src/com/openexchange/guard/pgp/decryption/PGPDecryptionResult.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.pgp.decryption;

import java.io.InputStream;

/**
 * Represents a decryption result
 *
 * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
 * @since v2.4.0
 */
public class PGPDecryptionResult {

    private final boolean hasSignature;
    private final boolean signatureVerified;
    private final boolean missingPublic;
    private final InputStream inputStream;
    private final String error;
    private final String contentType;


    /***
     *
     * Initializes a new {@link PGPDecryptionResult}.
     *
     * @param inputStream An inputStream to the decrypted data
     * @param contentType the data's content-type if available
     * @param hasSignature True, if the data was signed, false otherwise
     * @param signatureVerified True, if the data was signed and could be verified during decryption, false otherwise
     * @param error error value
     */
    public PGPDecryptionResult(InputStream inputStream, String contentType, boolean hasSignature, boolean signatureVerified, boolean missingPublic, String error) {
        this.inputStream = inputStream;
        this.contentType = contentType;
        this.hasSignature = hasSignature;
        this.signatureVerified = signatureVerified;
        this.missingPublic = missingPublic;
        this.error = error;
    }

    /**
     * @return True, if the data was signed, false otherwise
     */
    public boolean hasSignature() {
        return hasSignature;
    }

    /**
     * @return True, if the data was signed and could be verified during decryption, false otherwise
     */
    public boolean isSignatureVerified() {
        return signatureVerified;
    }

    /**
     *
     * @return True if the public key was missing to verify
     */
    public boolean isMissingPublic () {
    	return missingPublic;
    }
    /**
     * @return An InputStream to the decrypted data
     */
    public InputStream getInputStream() {
        return inputStream;
    }

    /**
     * Gets the contentType
     *
     * @return The contentType
     */
    public String getContentType() {
        return contentType;
    }

    /**
     * Return error if any
     * @return
     */
    public String getError() {
        return error;
    }

    /**
     * return true if has error
     * @return
     */
    public boolean hasError() {
        return (error != null);
    }
}
